@@ -31,6 +31,7 @@
 #include <glib.h>
 #include <libgnome/gnome-i18n.h>
 #include <gsf/gsf.h>
+#include <gsf-gnome/gsf-input-gnomevfs.h>
 #include <gsf/gsf-input-stdio.h>
 
 #include "debug.h"
@@ -39,20 +40,18 @@
 #include "presentation.h"
 #include "theme.h"
 
-struct _CriaPresentationPrivate
-{
+struct _CriaPresentationPrivate {
+	//GList		* master_slides;
 	GList		* slides;
 	GHashTable	* themes;
 };
 
-enum
-{
+enum {
 	PROP_0,
 	PROP_TITLE
 };
 
-enum
-{
+enum {
 	SIGNAL,
 	N_SIGNALS
 };
@@ -312,6 +311,33 @@ cria_presentation_new_from_input (
 	return presentation;
 }
 
+CriaPresentation*
+cria_presentation_new_from_uri(const gchar* text_uri) {
+	CriaPresentation* presentation;
+	GError		* error = NULL;
+	GsfInput	* input = NULL;
+
+	g_return_val_if_fail (text_uri != NULL, NULL);
+	g_return_val_if_fail (strlen (text_uri) > 0, NULL);
+	
+	input = GSF_INPUT (
+			gsf_input_gnomevfs_new (
+				text_uri,
+				&error)
+			);
+
+	if (error) {
+		g_warning ("(%s, %i): %s", __FILE__, __LINE__, error->message);
+		g_error_free (error);
+		return NULL;
+	}
+
+	presentation = cria_presentation_new_from_input (input);
+	
+	return presentation;
+
+}
+
 static void
 cria_presentation_set_property (
 		GObject		* object,
@@ -354,6 +380,13 @@ cria_presentation_set_title (
 	g_object_notify (G_OBJECT (self), "title");
 }
 
+void
+cria_presentation_add_master_slide(
+		CriaPresentation* self,
+		CriaSlide	* master_slide) {
+	// FIXME implement this one
+}
+
 /********************** this is the xml parser interface **********************/
 
 #include <glib/ghash.h>
@@ -964,5 +997,3 @@ static xmlSAXHandler cria_0_0_1_handler = {
 	NULL, // errorSAXFunc error;
 	NULL  // fatalErrorSAXFunc fatalError;
 };
-
-
