@@ -213,8 +213,8 @@ cria_slide_show_class_init (CriaSlideShowClass	* cria_slide_show_class)
 			g_param_spec_uint (
 				"slide",
 				"Slide",
-				"The slide that's presented in this moment or that we're \
-				currently switching to",
+				"The slide that's presented in this moment or that we're "
+				"currently switching to",
 				0,
 				G_MAXUINT,
 				0,
@@ -427,6 +427,14 @@ cria_slide_show_next_page_event (
 	}
 }
 
+GtkWidget*
+cria_slide_show_new(CriaPresentation* p) {
+	g_assert(p != NULL);
+	g_assert(CRIA_IS_PRESENTATION(p));
+
+	return g_object_new(CRIA_TYPE_SLIDE_SHOW, "presentation", p, NULL);
+}
+
 static void
 cria_slide_show_prev_page_event (
 		GtkGestureHandler *gh,
@@ -519,8 +527,7 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 
 	g_debug ("cria_slide_show_render_slide(): theme=0x%x layout=0x%x", (guint)theme, (guint)layout);
 	
-	if (theme && layout)
-	{
+	if (theme && layout) {
 		char	**blocks,
 			**iterator;
 		
@@ -542,7 +549,7 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 				"width-in-pixels", TRUE,
 				"width-set", TRUE,
 				NULL);
-
+		
 		/* 2 - render slide blocks */
 		/* 2.1 - get a list of block names from the layout */
 		blocks = cria_layout_get_block_names (layout);
